==> DRGNational2015_v1.20.zip: ModificariDB1.sql <==
USE [DRGNationalDB]
GO

BEGIN TRY
	SET QUOTED_IDENTIFIER ON
    BEGIN TRANSACTION

	--modificari Lista Sectii
	if exists(select * from sys.tables t
	inner join sys.columns c on c.object_id = t.object_id and t.name = 'ListaSectii' and c.name = 'DataExpirare')
	begin
		update ListaSectii set DataExpirare = '2017-04-01'  where CodSectie in ('1272.1','1272.2','1333')

		if not exists (select * from [dbo].[ListaSectii] where CodSectie = '1423.3')
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare]) 
		VALUES ('1423.3','Exceptie anexa 25: sectia de recuperare medicala neuropsihomotorie copii din cadrul spitalului CT11',0,'14233',NULL)

		if not exists (select * from [dbo].[ListaSectii] where CodSectie = '1423.4')
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare]) 
		VALUES ('1423.4','Exceptie anexa 25: compartimentul recuperare neuro-psiho-motorie din cadrul spitalului BH18',0,'14234',NULL)

		update [dbo].[ListaSectii] set DenSectie = 'Exceptie anexa 23C sectia de recuperare medicala neurologie din cadrul spitalului B_80'
		where CodSectie = '1393.4'
		print '1.15 - Update lista sectii - OK'
	end

	if exists(select * from sys.tables t
	inner join sys.columns c on c.object_id = t.object_id 
	and t.name = 'ListaCazRezolvatInterventiiChirurgicale' and c.name = 'DenCazRezolvatInterventieComplet')
	begin
		update ListaCazRezolvatInterventiiChirurgicale
		set DenCazRezolvatInterventieComplet = DenCazRezolvatInterventiiChirurgicale 
						+ case when DataValabilitate is not null then ' - ' + convert(varchar(20), ISNULL(DataValabilitate,''),103)
						  else '' end
	end

	if not exists(select * from ListaSectii where CodSectie='1393.4')
	begin
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare])
		VALUES ('1393.4','Exceptie anexa 23C sectia clinica(IV) de recuperare medicala neurologie din cadrul spitalului B_70',0,'13934',NULL)
	end

	--vers 1.19
	if not exists(select * from ListaSectii where CodSectie='1493')
	begin
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare])
		VALUES ('1493','Genetica medicala (acuti si cronici)',1,'1493',NULL)
	end

	print 'Update lista sectii - OK'

	--vers 1.20
	if not exists(select * from ListaAccidente where IdAccident='6')
	begin
		INSERT INTO [dbo].[ListaAccidente] ([IdAccident],[DenAccident])
		VALUES (6,'Infectie confirmata cu COVID-19')
	end

	if not exists(select * from ListaAccidente where IdAccident='7')
	begin
		INSERT INTO [dbo].[ListaAccidente] ([IdAccident],[DenAccident])
		VALUES (7,'Suspiciune/testare pentru infectie cu COVID-19, neconfirmata')
	end

	print 'Update lista accidente - OK'

	UPDATE DBVersion
	SET CurrentVersion = '1.20'
	print 'UPDATE DBVersion to 1.20 - OK'

    COMMIT
END TRY
BEGIN CATCH
 print 'Eroare nr. ' + cast(ERROR_NUMBER() as varchar(50)) + ' la linia ' + cast(ERROR_LINE() as varchar(50)) + ' cu mesajul ' + ERROR_MESSAGE()
 ROLLBACK
END CATCH

==> DRGNational2015_v1.21.zip: ModificariDB1.sql <==
USE [DRGNationalDB]
GO

BEGIN TRY
	SET QUOTED_IDENTIFIER ON
    BEGIN TRANSACTION

	--modificari Lista Sectii
	if exists(select * from sys.tables t
	inner join sys.columns c on c.object_id = t.object_id and t.name = 'ListaSectii' and c.name = 'DataExpirare')
	begin
		update ListaSectii set DataExpirare = '2017-04-01'  where CodSectie in ('1272.1','1272.2','1333')

		if not exists (select * from [dbo].[ListaSectii] where CodSectie = '1423.3')
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare]) 
		VALUES ('1423.3','Exceptie anexa 25: sectia de recuperare medicala neuropsihomotorie copii din cadrul spitalului CT11',0,'14233',NULL)

		if not exists (select * from [dbo].[ListaSectii] where CodSectie = '1423.4')
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare]) 
		VALUES ('1423.4','Exceptie anexa 25: compartimentul recuperare neuro-psiho-motorie din cadrul spitalului BH18',0,'14234',NULL)

		update [dbo].[ListaSectii] set DenSectie = 'Exceptie anexa 23C sectia de recuperare medicala neurologie din cadrul spitalului B_80'
		where CodSectie = '1393.4'
		print '1.15 - Update lista sectii - OK'
	end

	if exists(select * from sys.tables t
	inner join sys.columns c on c.object_id = t.object_id 
	and t.name = 'ListaCazRezolvatInterventiiChirurgicale' and c.name = 'DenCazRezolvatInterventieComplet')
	begin
		update ListaCazRezolvatInterventiiChirurgicale
		set DenCazRezolvatInterventieComplet = DenCazRezolvatInterventiiChirurgicale 
						+ case when DataValabilitate is not null then ' - ' + convert(varchar(20), ISNULL(DataValabilitate,''),103)
						  else '' end
	end

	if not exists(select * from ListaSectii where CodSectie='1393.4')
	begin
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare])
		VALUES ('1393.4','Exceptie anexa 23C sectia clinica(IV) de recuperare medicala neurologie din cadrul spitalului B_70',0,'13934',NULL)
	end

	--vers 1.19
	if not exists(select * from ListaSectii where CodSectie='1493')
	begin
		INSERT INTO [dbo].[ListaSectii]([CodSectie],[DenSectie],[Acut],[CodSectieInt],[DataExpirare])
		VALUES ('1493','Genetica medicala (acuti si cronici)',1,'1493',NULL)
	end

	print 'Update lista sectii - OK'

	--vers 1.20
	if not exists(select * from ListaAccidente where IdAccident='6')
	begin
		INSERT INTO [dbo].[ListaAccidente] ([IdAccident],[DenAccident])
		VALUES (6,'Infectie confirmata cu COVID-19')
	end

	if not exists(select * from ListaAccidente where IdAccident='7')
	begin
		INSERT INTO [dbo].[ListaAccidente] ([IdAccident],[DenAccident])
		VALUES (7,'Suspiciune/testare pentru infectie cu COVID-19, neconfirmata')
	end

	print 'Update lista accidente - OK'

	--vers 1.21
	if not exists(select * from ListaDiagnosticeClase where IdClasaDiagnostic=22)
	begin
		INSERT INTO [dbo].[ListaDiagnosticeClase] ([IdClasaDiagnostic],[DenClasaDiagnostic])
		VALUES (22,'Coduri pentru scopuri speciale')
	end
	print 'v1.21 - Update ListaDiagnosticeClase - OK'

	if not exists(select * from ListaDiagnosticeSubClase where IdSubClasaDiagnostic=274)
	begin
		INSERT INTO [dbo].[ListaDiagnosticeSubClase] ([IdSubClasaDiagnostic],[IdClasaDiagnostic],[DenSubClasaDiagnostic])
		VALUES (274,22,'Afectiuni noi, de etiologie incerta, alocate temporar sau in situatii de urgenta U00-U49')
	end
	print 'v1.21 - Update ListaDiagnosticeSubClase - OK'

	if not exists(select * from ListaDiagnostice where IdDiagnostic=15928)
	begin
		INSERT INTO [dbo].[ListaDiagnostice] ([IdDiagnostic],[CodDiagnostic],[IdSubClasaDiagnostic],[DenDiagnostic],[Simplu],[Dagger],[Asterisk],[Traumatism],[CauzaExterna],[Sechela],[CodDenDiagnostic])
		VALUES(15928,'U07.1',274,'COVID-19, virus identificat',1,0,0,0,0,0,'U07.1 - COVID-19, virus identificat')
	end

	if not exists(select * from ListaDiagnostice where IdDiagnostic=15929)
	begin
		INSERT INTO [dbo].[ListaDiagnostice] ([IdDiagnostic],[CodDiagnostic],[IdSubClasaDiagnostic],[DenDiagnostic],[Simplu],[Dagger],[Asterisk],[Traumatism],[CauzaExterna],[Sechela],[CodDenDiagnostic])
		VALUES(15929,'U07.2',274,'COVID-19, virus neidentificat',1,0,0,0,0,0,'U07.2 - COVID-19, virus neidentificat')
	end
	print 'v1.21 - Update ListaDiagnostice - OK'

	UPDATE DBVersion
	SET CurrentVersion = '1.21'
	print 'UPDATE DBVersion to 1.21 - OK'

    COMMIT
END TRY
BEGIN CATCH
 print 'Eroare nr. ' + cast(ERROR_NUMBER() as varchar(50)) + ' la linia ' + cast(ERROR_LINE() as varchar(50)) + ' cu mesajul ' + ERROR_MESSAGE()
 ROLLBACK
END CATCH
